==> xoops-2.4.5.tbz: www/xoops/htdocs/language/english/banners.php <==
<?php
/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code
 which is considered copyrighted (c) material of the original comment or credit authors.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
* Xoops Language
*
* @copyright The XOOPS Project http://sourceforge.net/projects/xoops/
* @license http://www.fsf.org/copyleft/gpl.html GNU public license
* @package kernel
* @subpackage Xoops Banners Language
* @since 2.0.0
* @author Kazumi Ono <onokazu@xoops.org>
* @version $Id: banners.php 4052 2009-12-26 18:44:37Z trabis $
*/
defined('XOOPS_ROOT_PATH') or die('Restricted access');
// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
define('_BANNERS_MANAGEMENT', 'Advertising Managment');
define('_BANNERS_WELCOMEBACK', 'Welcome: %s');
define('_BANNERS_LOGGEDOUT', 'Logged out the advertisement panel');
define('_BANNERS_LOGOUT', 'Log Out Advertising Manager');
define('_BANNERS_LOGIN_TITLE', 'Advertising Statistics');
define('_BANNERS_LOGIN_LOGIN', 'Login :');
define('_BANNERS_LOGIN_INCORRECT', 'Incorrect Username or Password');
define('_BANNERS_LOGIN_PASS', 'Password :');
define('_BANNERS_LOGIN_INFO', 'Please type your client information');
define('_BANNERS_LOGIN_OK', 'OK');
define('_BANNERS_ID', 'Banner ID:');
define('_BANNERS_TITLE', 'Active Banners');
define('_BANNERS_URL', 'Change URL:');
define('_BANNERS_NOTHINGFOUND', 'No Records Found');
define('_BANNERS_NO', '#');
define('_BANNERS_FOW_IN', 'Displaying Active Banners: ');
define('_BANNERS_IMP_MADE', 'Imp. Made');
define('_BANNERS_IMP_TOTAL', 'Imp. Total');
define('_BANNERS_IMP_LEFT', 'Imp. Left');
define('_BANNERS_CLICKS', 'Clicks');
define('_BANNERS_PER_CLICKS', '% Clicks');
define('_BANNERS_FUNCTIONS', 'Functions');
define('_BANNERS_STATS', 'E-mail Stats');
define('_BANNERS_SHOWBANNER', 'Show Banner');
define('_BANNERS_SEND_STATS', 'Send <a href=\'%s\' title=\'E-mail Stats\'/>E-mail Stats</a> for this Banner');
define('_BANNERS_POINTS', 'This Banner points to <a href=\'%s\' title=\'\'>this URL</a>');
define('_BANNERS_UNLIMITED', 'Unlimited');
define('_BANNERS_FINISHED', 'Expired Banners');
define('_BANNERS_STARTED', 'Start Date');
define('_BANNERS_ENDED', 'End Date');
define('_BANNERS_MAIL_SUBJECT', 'Your Banner Statistics at %s');
define('_BANNERS_MAIL_MESSAGE', 'Available Advertising Statistics for the selected Banner at %s :\n\n\n
Client Name: %s\nBanner ID: %s\n
Banner Image: %s\n
Banner URL: %s\n\n
Impressions Purchased: %s\n
Impressions Made: %s\n
Impressions Left: %s\n
Clicks Received: %s\n
Clicks Percent: %f \n\n\n
Report Generated on: %s');
define('_BANNERS_MAIL_NOT_OK', 'We have encountered an error sending your email. Please contact the webmaster regarding this issue.');
define('_BANNERS_MAIL_OK', 'Available advertising statistics for the selected banner have been sent to your account email address.');
define('_BANNERS_MAIL_ERROR', 'There is no email associated with client %s.<br />Please contact the Administrator');
define('_BANNERS_DBUPDATED', 'Item modified and database updated');
define('_BANNERS_DBERROR', 'Database was not updated due to an error!');
define('_BANNERS_CHANGE', 'Change');

define('_BANNERS_NO_LOGIN_DATA', 'No login data detected');
define('_BANNERS_NO_REFERER', 'No referer detected');
define('_BANNERS_NO_ID', 'No valid ID detected');
?>

==> xoops-2.5.5.tbz: www/xoops/htdocs/language/english/banners.php <==
<?php
// $Id: banners.php 8066 2011-11-06 05:09:33Z beckmi $
// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
define('_BANNERS_MANAGEMENT', 'Banner Management');
define('_BANNERS_WELCOMEBACK', 'Welcome back: %s');
//define('_BANNERS_LOGGEDOUT', 'Logged out the advertisement panel');
define('_BANNERS_LOGOUT', 'Logout Banner Management');
define('_BANNERS_LOGIN_TITLE', 'Banner Statistics');
define('_BANNERS_LOGIN_LOGIN', 'Login :');
define('_BANNERS_LOGIN_INCORRECT', 'Incorrect Username or Password');
define('_BANNERS_LOGIN_PASS', 'Password :');
define('_BANNERS_LOGIN_INFO', 'Please type your client information');
define('_BANNERS_LOGIN_OK', 'OK');
define('_BANNERS_ID', 'Banner ID:');
define('_BANNERS_TITLE', 'Active Banners');
define('_BANNERS_URL', 'Change URL:');
define('_BANNERS_NOTHINGFOUND', 'No Banners Found');
define('_BANNERS_NO', '#');
define('_BANNERS_FOW_IN', 'Displaying Active Banners: ');
define('_BANNERS_IMP_MADE', 'Imp. Made');
define('_BANNERS_IMP_TOTAL', 'Imp. Total');
define('_BANNERS_IMP_LEFT', 'Imp. Left');
define('_BANNERS_CLICKS', 'Clicks');
define('_BANNERS_PER_CLICKS', '% Clicks');
define('_BANNERS_FUNCTIONS', 'Functions');
define('_BANNERS_STATS', 'Email Stats');
define('_BANNERS_SHOWBANNER', 'Show Banner');
define('_BANNERS_SEND_STATS', 'Send <a href=\'%s\' title=\'E-mail Stats\'/>Email Stats</a> for this Banner');
define('_BANNERS_POINTS', 'This Banner points to <a href=\'%s\' title=\'\'>this URL</a>');
define('_BANNERS_UNLIMITED', 'Unlimited');
define('_BANNERS_FINISHED', 'Expired Banners');
define('_BANNERS_STARTED', 'Start Date');
define('_BANNERS_ENDED', 'End Date');
define('_BANNERS_MAIL_SUBJECT', 'Your Banner Statistics at %s');
define('_BANNERS_MAIL_MESSAGE', 'Available Banner Statistics for the selected Banner at %s :\n\n\n
Client Name: %s\nBanner ID: %s\n
Banner Image: %s\n
Banner URL: %s\n\n
Impressions Purchased: %s\n
Impressions Made: %s\n
Impressions Left: %s\n
Clicks Received: %s\n
Clicks Percent: %f \n\n\n
Report Generated on: %s');
define('_BANNERS_MAIL_NOT_OK', 'We have encountered an error sending your email. Please contact the webmaster regarding this issue.');
define('_BANNERS_MAIL_OK', 'Available Banner statistics for the selected banner have been sent to your account email address.');
define('_BANNERS_MAIL_ERROR', 'There is no email associated with client %s.<br />Please contact the Administrator');
define('_BANNERS_DBUPDATED', 'Item modified and database updated');
define('_BANNERS_DBERROR', 'Database was not updated due to an error!');
define('_BANNERS_CHANGE', 'Change');

define('_BANNERS_NO_LOGIN_DATA', 'No login data detected');
define('_BANNERS_NO_REFERER', 'No referer detected');
define('_BANNERS_NO_ID', 'No valid ID detected');
?>
